package org.jtheque.utils;

import org.apache.commons.logging.LogFactory;

import java.sql.SQLException;
import java.sql.ResultSet;
import java.sql.Statement;
import java.sql.Connection;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * An utility class for database use.
 *
 * @author Baptiste Wicht
 */
public final class DatabaseUtils {
    /**
     * Construct a new DatabaseUtils. This class is an utility class, it cannot be instanciated.
     *
     */
    private DatabaseUtils() {
        super();
    }

    /**
     * Close the result set.
     *
     * @param rs The result set to close.
     */
    public static void close(ResultSet rs){
        if(rs != null){
            try {
                rs.close();
            } catch (SQLException e) {
                LogFactory.getLog(DatabaseUtils.class).error("Unable to close resultset", e);
            }
        }
    }

    /**
     * Close the statement.
     *
     * @param statement The statement to close.
     */
    public static void close(Statement statement){
        if (statement != null) {
            try {
                statement.close();
            } catch (SQLException e) {
            LogFactory.getLog(DatabaseUtils.class).error("Unable to close statement", e);
            }
        }
    }

    /**
     * Close the connection.
     *
     * @param connection The connection to close.
     */
    public static void close(Connection connection){
        if (connection != null) {
            try {
                connection.close();
            } catch (SQLException e) {
            LogFactory.getLog(DatabaseUtils.class).error("Unable to close connection", e);
            }
        }
    }
}
